httputil

package
v0.0.0-...-6c5c7c9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AppendHeaderOptions

func AppendHeaderOptions(opts []option.RequestOption, headers map[string]string) []option.RequestOption

AppendHeaderOptions appends non-empty header values as OpenAI request options.

func GetJSON

func GetJSON(ctx context.Context, url string, headers map[string]string, timeoutSecs int) ([]byte, int, error)

GetJSON sends a GET request with the given headers and returns the response body.

func MergeHeaders

func MergeHeaders(base, override map[string]string) map[string]string

MergeHeaders merges override headers into base, returning a new map.

func PostJSON

func PostJSON(ctx context.Context, url string, headers map[string]string, payload any, timeoutSecs int) ([]byte, int, error)

PostJSON marshals payload as JSON and sends a POST request with the given headers. Returns the response body, status code, and any error.

Types

This section is empty.

Jump to